package cn.ibizlab.demoapi.dto;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.math.BigInteger;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.alibaba.fastjson.annotation.JSONField;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import cn.ibizlab.util.domain.DTOBase;
import cn.ibizlab.util.domain.DTOClient;
import lombok.Data;

/**
 * 服务DTO对象[IBIZHardwareDTO]
 */
@Data
public class IBIZHardwareDTO extends DTOBase implements Serializable {

	private static final long serialVersionUID = 1L;

    /**
     * 属性 [UNIT]
     *
     */
    @JSONField(name = "unit")
    @JsonProperty("unit")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String unit;

    /**
     * 属性 [UPDATEMAN]
     *
     */
    @JSONField(name = "updateman")
    @JsonProperty("updateman")
    @Size(min = 0, max = 60, message = "内容长度必须小于等于[60]")
    private String updateman;

    /**
     * 属性 [IBIZHARDWARETYPE]
     *
     */
    @JSONField(name = "ibizhardwaretype")
    @JsonProperty("ibizhardwaretype")
    @NotBlank(message = "[分组类型]不允许为空!")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String ibizhardwaretype;

    /**
     * 属性 [CREATEMAN]
     *
     */
    @JSONField(name = "createman")
    @JsonProperty("createman")
    @Size(min = 0, max = 60, message = "内容长度必须小于等于[60]")
    private String createman;

    /**
     * 属性 [UPDATEDATE]
     *
     */
    @JsonFormat(pattern="yyyy-MM-dd HH:mm:ss", locale = "zh" , timezone="GMT+8")
    @JSONField(name = "updatedate" , format="yyyy-MM-dd HH:mm:ss")
    @JsonProperty("updatedate")
    private Timestamp updatedate;

    /**
     * 属性 [CREATEDATE]
     *
     */
    @JsonFormat(pattern="yyyy-MM-dd HH:mm:ss", locale = "zh" , timezone="GMT+8")
    @JSONField(name = "createdate" , format="yyyy-MM-dd HH:mm:ss")
    @JsonProperty("createdate")
    private Timestamp createdate;

    /**
     * 属性 [PRODUCTUID]
     *
     */
    @JSONField(name = "productuid")
    @JsonProperty("productuid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String productuid;

    /**
     * 属性 [IBIZHARDWAREID]
     *
     */
    @JSONField(name = "ibizhardwareid")
    @JsonProperty("ibizhardwareid")
    @Size(min = 0, max = 100, message = "内容长度必须小于等于[100]")
    private String ibizhardwareid;

    /**
     * 属性 [IBIZHARDWARENAME]
     *
     */
    @JSONField(name = "ibizhardwarename")
    @JsonProperty("ibizhardwarename")
    @Size(min = 0, max = 200, message = "内容长度必须小于等于[200]")
    private String ibizhardwarename;

    /**
     * 属性 [UNITPRICE]
     *
     */
    @JSONField(name = "unitprice")
    @JsonProperty("unitprice")
    private Double unitprice;

    /**
     * 属性 [PRODUCER]
     *
     */
    @JSONField(name = "producer")
    @JsonProperty("producer")
    @Size(min = 0, max = 2000, message = "内容长度必须小于等于[2000]")
    private String producer;


    /**
     * 设置 [UNIT]
     */
    public void setUnit(String  unit){
        this.unit = unit ;
        this.modify("unit",unit);
    }

    /**
     * 设置 [IBIZHARDWARETYPE]
     */
    public void setIbizhardwaretype(String  ibizhardwaretype){
        this.ibizhardwaretype = ibizhardwaretype ;
        this.modify("ibizhardwaretype",ibizhardwaretype);
    }

    /**
     * 设置 [PRODUCTUID]
     */
    public void setProductuid(String  productuid){
        this.productuid = productuid ;
        this.modify("productuid",productuid);
    }

    /**
     * 设置 [IBIZHARDWARENAME]
     */
    public void setIbizhardwarename(String  ibizhardwarename){
        this.ibizhardwarename = ibizhardwarename ;
        this.modify("ibizhardwarename",ibizhardwarename);
    }

    /**
     * 设置 [UNITPRICE]
     */
    public void setUnitprice(Double  unitprice){
        this.unitprice = unitprice ;
        this.modify("unitprice",unitprice);
    }

    /**
     * 设置 [PRODUCER]
     */
    public void setProducer(String  producer){
        this.producer = producer ;
        this.modify("producer",producer);
    }


}


